@@ -172,9 +172,10 @@ class TestSetupCommand:
         mock_scripts.return_value = {"installed": [], "updated": [], "errors": []}
 
         mock_hooks_instance = MagicMock()
+        # PreToolUse now in removed (legacy spam) not fixed (GitHub #13439)
         mock_hooks_instance.cleanup_legacy_hooks.return_value = {
-            "removed": ["SessionStart", "SessionEnd"],
-            "fixed": ["PreToolUse"]
+            "removed": ["SessionStart", "SessionEnd", "PreToolUse"],
+            "fixed": []
         }
         mock_hooks_instance.install_hooks.return_value = {"installed": [], "skipped": [], "blocked": []}
         mock_hooks_class.return_value = mock_hooks_instance
@@ -187,8 +188,7 @@ class TestSetupCommand:
 
         result = runner.invoke(setup, input="ABCD-1234-EFGH\n")
 
-        assert "Removed: SessionStart, SessionEnd" in result.output
-        assert "Fixed: PreToolUse" in result.output
+        assert "Removed: SessionStart, SessionEnd, PreToolUse" in result.output
 
 
 class TestStatusCommand:
@@ -200,7 +200,8 @@ class TestStatusCommand:
         mock_config.is_configured.return_value = False
 
         mock_hooks_instance = MagicMock()
-        mock_hooks_instance.get_hook_status.return_value = {"Stop": False, "PreToolUse": False, "PermissionRequest": False}
+        # PreToolUse removed from hooks (GitHub #13439)
+        mock_hooks_instance.get_hook_status.return_value = {"Stop": False, "PermissionRequest": False}
         mock_hooks_class.return_value = mock_hooks_instance
 
         result = runner.invoke(status)
@@ -215,7 +216,8 @@ class TestStatusCommand:
         mock_config.format_token_display.return_value = "ABCD-1234-EFGH"
 
         mock_hooks_instance = MagicMock()
-        mock_hooks_instance.get_hook_status.return_value = {"Stop": True, "PreToolUse": True, "PermissionRequest": True}
+        # PreToolUse removed from hooks (GitHub #13439)
+        mock_hooks_instance.get_hook_status.return_value = {"Stop": True, "PermissionRequest": True}
         mock_hooks_class.return_value = mock_hooks_instance
 
         result = runner.invoke(status)
@@ -231,18 +233,17 @@ class TestStatusCommand:
         mock_config.get_auth_token.return_value = "ABCD1234EFGH"
 
         mock_hooks_instance = MagicMock()
+        # PreToolUse removed from hooks (GitHub #13439)
         mock_hooks_instance.get_hook_status.return_value = {
             "Stop": True,
-            "PreToolUse": False,
             "PermissionRequest": True
         }
         mock_hooks_class.return_value = mock_hooks_instance
 
         result = runner.invoke(status)
 
-        # Check hooks are shown
+        # Check hooks are shown (PreToolUse removed)
         assert "Stop" in result.output
-        assert "PreToolUse" in result.output
         assert "PermissionRequest" in result.output
 
 
@@ -320,8 +321,9 @@ class TestHookCommands:
     def test_install_hooks_command(self, mock_installer_class, runner):
         """install-hooks command installs hooks."""
         mock_instance = MagicMock()
-        mock_instance.get_hook_status.return_value = {"Stop": False, "PreToolUse": False, "PermissionRequest": False}
-        mock_instance.install_hooks.return_value = {"installed": ["Stop", "PreToolUse"], "skipped": [], "blocked": []}
+        # PreToolUse removed from hooks (GitHub #13439)
+        mock_instance.get_hook_status.return_value = {"Stop": False, "PermissionRequest": False}
+        mock_instance.install_hooks.return_value = {"installed": ["Stop", "PermissionRequest"], "skipped": [], "blocked": []}
         mock_installer_class.return_value = mock_instance
 
         result = runner.invoke(install_hooks)
@@ -334,7 +336,8 @@ class TestHookCommands:
     def test_install_hooks_already_installed(self, mock_installer_class, runner):
         """install-hooks shows message when all installed."""
         mock_instance = MagicMock()
-        mock_instance.get_hook_status.return_value = {"Stop": True, "PreToolUse": True, "PermissionRequest": True}
+        # PreToolUse removed from hooks (GitHub #13439)
+        mock_instance.get_hook_status.return_value = {"Stop": True, "PermissionRequest": True}
         mock_installer_class.return_value = mock_instance
 
         result = runner.invoke(install_hooks)
@@ -347,7 +350,8 @@ class TestHookCommands:
     def test_uninstall_hooks_command_confirmed(self, mock_installer_class, runner):
         """uninstall-hooks removes hooks when confirmed."""
         mock_instance = MagicMock()
-        mock_instance.uninstall_hooks.return_value = {"removed": ["Stop", "PreToolUse"], "total": 2}
+        # PreToolUse removed from hooks (GitHub #13439)
+        mock_instance.uninstall_hooks.return_value = {"removed": ["Stop", "PermissionRequest"], "total": 2}
         mock_installer_class.return_value = mock_instance
 
         result = runner.invoke(uninstall_hooks, input="y\n")
@@ -384,9 +388,10 @@ class TestHookCommands:
     def test_fix_hooks_command(self, mock_installer_class, runner):
         """fix-hooks cleans legacy spam hooks."""
         mock_instance = MagicMock()
+        # PreToolUse now in removed (legacy spam) not fixed (GitHub #13439)
         mock_instance.cleanup_legacy_hooks.return_value = {
-            "removed": ["SessionStart", "Notification"],
-            "fixed": ["PreToolUse"]
+            "removed": ["SessionStart", "Notification", "PreToolUse"],
+            "fixed": []
         }
         mock_installer_class.return_value = mock_instance
 
