@@ -14,7 +14,8 @@ class HooksInstaller:
 
     # ALLOWED hook types - ONLY these can be installed
     # PermissionRequest IS a valid Claude Code hook event (fires only for permission dialogs)
-    ALLOWED_HOOK_TYPES = frozenset({"Stop", "PreToolUse", "PermissionRequest"})
+    # NOTE: PreToolUse removed - causes stdin conflict with AskUserQuestion (GitHub #13439)
+    ALLOWED_HOOK_TYPES = frozenset({"Stop", "PermissionRequest"})
 
     # BLOCKED hook types - these MUST NEVER be installed (cause spam)
     BLOCKED_SPAM_HOOKS = frozenset({
@@ -43,6 +44,7 @@ class HooksInstaller:
         "PermissionRequest": [
             {
                 # Send notification for permission dialogs (Bash, Write, Edit, etc.)
+                # Also handles AskUserQuestion (multi-choice questions) via handle_ask_user_question()
                 "hooks": [
                     {
                         "type": "command",
@@ -50,19 +52,9 @@ class HooksInstaller:
                     }
                 ]
             }
-        ],
-        "PreToolUse": [
-            {
-                # Send notification for AskUserQuestion tool (questions)
-                "matcher": "AskUserQuestion",
-                "hooks": [
-                    {
-                        "type": "command",
-                        "command": "watchcode notify --event question --requires-action"
-                    }
-                ]
-            }
         ]
+        # NOTE: PreToolUse removed - caused double notifications and stdin conflict
+        # with AskUserQuestion (GitHub #13439). PermissionRequest handles questions.
     }
 
     def __init__(self):
@@ -254,16 +246,17 @@ class HooksInstaller:
         return status
 
     # Legacy spam hooks that should be cleaned up
-    LEGACY_SPAM_HOOKS = {"SessionStart", "SessionEnd", "Notification"}
+    # PreToolUse added - causes stdin conflict with AskUserQuestion (GitHub #13439)
+    LEGACY_SPAM_HOOKS = {"SessionStart", "SessionEnd", "Notification", "PreToolUse"}
 
     def cleanup_legacy_hooks(self) -> Dict[str, Any]:
         """Remove legacy spam hooks that should never have been installed.
 
-        These hooks cause notification spam:
+        These hooks cause notification spam or bugs:
         - SessionStart: fires on every session start
         - SessionEnd: fires on every session end
         - Notification: fires on random notifications
-        - PreToolUse without matcher: fires on EVERY tool use
+        - PreToolUse: causes stdin conflict with AskUserQuestion (GitHub #13439)
 
         Returns:
             Dictionary with cleanup results.
@@ -291,26 +284,8 @@ class HooksInstaller:
                         del settings["hooks"][spam_hook]
                     removed.append(spam_hook)
 
-        # Fix PreToolUse - ensure it has valid matchers (AskUserQuestion or Bash)
-        VALID_PRETOOLUSE_MATCHERS = {"AskUserQuestion", "Bash"}
-        if "PreToolUse" in settings["hooks"]:
-            hooks_list = settings["hooks"]["PreToolUse"]
-            new_hooks = []
-            for hook in hooks_list:
-                if self.is_watchcode_hook(hook):
-                    # Check if it has a valid matcher
-                    matcher = hook.get("matcher")
-                    if matcher not in VALID_PRETOOLUSE_MATCHERS:
-                        # This is a spam hook (no matcher or wrong matcher)
-                        fixed.append("PreToolUse")
-                        continue  # Remove it
-                new_hooks.append(hook)
-
-            # Add correct PreToolUse hooks if we removed bad ones
-            if "PreToolUse" in fixed:
-                new_hooks.extend(self.WATCHCODE_HOOKS["PreToolUse"])
-
-            settings["hooks"]["PreToolUse"] = new_hooks
+        # NOTE: PreToolUse fix logic removed - PreToolUse is now in LEGACY_SPAM_HOOKS
+        # and will be fully removed by the loop above (GitHub #13439)
 
         self.save_settings(settings)
 
